(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     39409,        858]
NotebookOptionsPosition[     39762,        847]
NotebookOutlinePosition[     40227,        867]
CellTagsIndexPosition[     40184,        864]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Stress at a point\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2019-03-02",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "The following module demonstrate the concept of stress at a point. \n\
Consider a body applied with traction (or displacement) on the boundary. To \
investigate the stress of a point inside, cut the body with a plane. Without \
losing generality, choose the plane perpendicular to z-axis. Consider a small \
area on the plane with size ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]A", "z"], TraditionalForm]]],
 ", acted with a force ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]F", "z"], TraditionalForm]]],
 " which has components of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalDelta]F", "zx"], ",", 
    SubscriptBox["\[CapitalDelta]F", "zy"]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalDelta]F", "zz"], TraditionalForm]]],
 ". Then the stresses can be defined as"
}], "Text"],

Cell[TextData[Cell[BoxData[{
 FormBox[
  RowBox[{
   SubscriptBox["\[Tau]", "zx"], "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]A", "z"], "\[RightArrow]", "0"}]], 
    RowBox[{
     SubscriptBox["\[CapitalDelta]F", "zx"], "/", 
     SubscriptBox["\[CapitalDelta]A", "z"]}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   SubscriptBox["\[Tau]", "zy"], "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]A", "z"], "\[RightArrow]", "0"}]], 
    RowBox[{
     SubscriptBox["\[CapitalDelta]F", "zy"], "/", 
     SubscriptBox["\[CapitalDelta]A", "z"]}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   SubscriptBox["\[Sigma]", "zz"], "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]A", "z"], "\[RightArrow]", "0"}]], 
    RowBox[{
     SubscriptBox["\[CapitalDelta]F", "zz"], "/", 
     SubscriptBox["\[CapitalDelta]A", "z"]}]}]}], TraditionalForm]}]]], "Text",
 TextAlignment->Center],

Cell["\<\
The general state of stress at this point can be obtained if we take a stress \
cube out and look at the stress at the remaining surfaces. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`def$$ = 0, $CellContext`mx$$ = 
    0, $CellContext`show$$ = 0, $CellContext`t1$$ = 0, $CellContext`ts$$ = 3, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`show$$], 0, 
       Spacer[0]}, {1 -> "on", 0 -> "off"}}, {{
       Hold[$CellContext`def$$], 0, 
       Spacer[0]}, {1 -> "on", 0 -> "off"}}, {{
       Hold[$CellContext`t1$$], 0, 
       Text[
        Style["stress components", Bold, 12]]}, 0, 5}, {{
       Hold[$CellContext`ts$$], 3, 
       Spacer[0]}, {1 -> Text[
         Style[
          Grid[{{"x face"}}], Bold]], 2 -> Text[
         Style[
          Grid[{{"y face"}}], Bold]], 3 -> Text[
         Style[
          Grid[{{"z face"}}], Bold]]}}, {{
       Hold[$CellContext`mx$$], 0, 
       Spacer[0]}, {1 -> "on", 0 -> "off"}}, {
      Hold[
       Grid[{{
          Text[
           Style["stress at a point", Bold, 12]]}, {
          Manipulate`Place[1]}, {
          PaneSelector[{1 -> Grid[{{
                Text[
                 Style[
                  
                  Grid[{{"stress definition"}, {"(z face as example)"}}, 
                   Alignment -> Left], Bold, 12]]}, {
                Manipulate`Place[2]}, {
                PaneSelector[{1 -> Grid[{{
                    Text[
                    Subscript[
                    Style["\[Tau]", Bold], "zx"]], 
                    Text["="], 
                    Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\*SubscriptBox[\(\
\[CapitalDelta]A\), \(z\)] \[RightArrow] 0\)]\)", Bold, 12]], 
                    Text[
                    Style[
                    "\!\(\*SubscriptBox[\(\[CapitalDelta]F\), \
\(zx\)]\)/\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]A\",\n\
FontSize->12], \"z\"]\)", Bold, 12]]}, {
                    Text[
                    Subscript[
                    Style["\[Tau]", Bold], "zy"]], 
                    Text["="], 
                    Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\*SubscriptBox[\(\
\[CapitalDelta]A\), \(z\)] \[RightArrow] 0\)]\)", Bold, 12]], 
                    Text[
                    Style[
                    "\!\(\*SubscriptBox[\(\[CapitalDelta]F\), \
\(zy\)]\)/\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]A\",\n\
FontSize->12], \"z\"]\)", Bold, 12]]}, {
                    Text[
                    Subscript[
                    Style["\[Sigma]", Bold], "zz"]], 
                    Text["="], 
                    Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\*SubscriptBox[\(\
\[CapitalDelta]A\), \(z\)] \[RightArrow] 0\)]\)", Bold, 12]], 
                    Text[
                    Style[
                    "\!\(\*SubscriptBox[\(\[CapitalDelta]F\), \
\(zz\)]\)/\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]A\",\n\
FontSize->12], \"z\"]\)", Bold, 12]]}}]}, 
                 Dynamic[$CellContext`def$$]]}, {
                Manipulate`Place[3]}, {
                PaneSelector[{1 -> Grid[{{
                    Manipulate`Place[4]}, {
                    Text[
                    Style[
                    Grid[{{"stress tensor"}}, Alignment -> Left], Bold, 
                    12]]}, {
                    Manipulate`Place[5]}}, Alignment -> Left, 
                    Spacings -> {1, 1}]}, 
                 Dynamic[
                  
                  UnitStep[$CellContext`t1$$ - ($CellContext`t1max - 
                   0.001)]]]}, {
                PaneSelector[{1 -> Grid[{{
                    Text[
                    Style["\[Sigma]", Bold, 12]], 
                    Text[
                    Style["=", Bold, 12]], 
                    Text[
                    Style[
                    
                    MatrixForm[{{
                    
                    "\!\(\*SubscriptBox[\n StyleBox[\"\[Sigma]\",\n\
FontSize->12], \"xx\"]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(xy\)]\)", 
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(xz\)]\)"}, {
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(yx\)]\)", 
                    "\!\(\*SubscriptBox[\n StyleBox[\"\[Sigma]\",\n\
FontSize->12], \"yy\"]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(yz\)]\)"}, {
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(zx\)]\)", 
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(zy\)]\)", 
                    "\!\(\*SubscriptBox[\n StyleBox[\"\[Sigma]\",\n\
FontSize->12], \"zz\"]\)"}}], Bold, 12]]}}]}, 
                 Dynamic[
                 UnitStep[$CellContext`t1$$ - ($CellContext`t1max - 
                    0.001)] $CellContext`mx$$]]}}, Alignment -> Left, 
              Spacings -> {1, 1}]}, 
           Dynamic[$CellContext`show$$]]}}, Alignment -> Left, 
        Spacings -> {1, 1}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {600., {296., 304.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`show$428618$$ = False, $CellContext`def$428619$$ = 
    False, $CellContext`t1$428620$$ = 0, $CellContext`ts$428621$$ = 
    False, $CellContext`mx$428622$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`def$$ = 0, $CellContext`mx$$ = 
        0, $CellContext`show$$ = 0, $CellContext`t1$$ = 0, $CellContext`ts$$ = 
        3}, "ControllerVariables" :> {
        Hold[$CellContext`show$$, $CellContext`show$428618$$, False], 
        Hold[$CellContext`def$$, $CellContext`def$428619$$, False], 
        Hold[$CellContext`t1$$, $CellContext`t1$428620$$, 0], 
        Hold[$CellContext`ts$$, $CellContext`ts$428621$$, False], 
        Hold[$CellContext`mx$$, $CellContext`mx$428622$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`g$, $CellContext`k$, $CellContext`pg$ = 
         3, $CellContext`v1$ = 1, $CellContext`v2$ = 1, $CellContext`x1$ = 
         0, $CellContext`z1$ = 0.5, $CellContext`s1$ = 
         0.5, $CellContext`xt$, $CellContext`zt$, $CellContext`vs$, \
$CellContext`st$, $CellContext`stmax$, $CellContext`r$ = 
         7.25, $CellContext`thmax$ = 
         0.761, $CellContext`vth$, $CellContext`tht$, $CellContext`arr$ = 
         0.8, $CellContext`ac$, $CellContext`t2$, $CellContext`fig1$, \
$CellContext`fig2$, $CellContext`fig3$, $CellContext`fig4$, \
$CellContext`fig5$, $CellContext`fig6$, $CellContext`fig7$, \
$CellContext`fig8$, $CellContext`fig9$, $CellContext`fig10$, \
$CellContext`fig11$, $CellContext`fig13$, $CellContext`fig14$, \
$CellContext`fig15$, $CellContext`fig16$, $CellContext`fig17$, \
$CellContext`setting1$, $CellContext`colorx$, $CellContext`colory$, \
$CellContext`colorzm$, $CellContext`opcx$, $CellContext`opcy$, \
$CellContext`opcz$, $CellContext`ptz$}, $CellContext`t2$ = $CellContext`t1$$/
          5; $CellContext`vs$ = 
         1.35; $CellContext`st$ = ($CellContext`vs$ $CellContext`t2$) 
          UnitStep[$CellContext`t2$ - 
            0.001]; $CellContext`stmax$ = $CellContext`vs$ $CellContext`t2max; \
$CellContext`vth$ = $CellContext`thmax$/$CellContext`t1max; $CellContext`tht$ = \
$CellContext`thmax$ - $CellContext`vth$ $CellContext`t1$$; $CellContext`xt$ = \
$CellContext`r$ Sin[$CellContext`thmax$] - $CellContext`r$ 
          Sin[$CellContext`tht$]; $CellContext`zt$ = $CellContext`r$ 
           Cos[$CellContext`tht$] - $CellContext`r$ 
          Cos[$CellContext`thmax$]; $CellContext`colorx$ = 
         If[$CellContext`ts$$ == 1, Red, Gray]; $CellContext`colory$ = 
         If[$CellContext`ts$$ == 2, Red, Gray]; $CellContext`colorzm$ = 
         If[$CellContext`ts$$ == 3, Red, Gray]; $CellContext`opcx$ = 
         If[$CellContext`ts$$ == 1, 0.3, 0.1]; $CellContext`opcy$ = 
         If[$CellContext`ts$$ == 2, 0.3, 0.1]; $CellContext`opcz$ = 
         If[$CellContext`ts$$ == 3, 0.3, 0.1]; $CellContext`ptz$ = {{0.5, 0.5,
           2.7}, {0.25, 0.25, 1.05}}; $CellContext`setting1$ = {
          PlotRange -> {{-3, 10}, {-3, 3}, {-3, 6}}, Boxed -> False, 
           ImagePadding -> 0.1, ImageMargins -> 0, SphericalRegion -> True, 
           ViewAngle -> 0.03490658503988659, 
           ViewPoint -> {14.132364122761526`, -23.531265059130227`, 
            7.453517075927453}, 
           ViewVertical -> {-0.06292719835196123, 0.2976656300221665, 
            2.1417867317830304`}, ImageSize -> 400, Antialiasing -> 
           True}; $CellContext`fig1$ = {
           Opacity[0.3], 
           EdgeForm[], 
           Ellipsoid[{0, 0, 0}, {2, 2, 3}], {
            FaceForm[Red], 
            Polygon[
             Map[Append[#, 1]& , 
              CirclePoints[1.886, 50]]]}, {
            Opacity[1], 
            Thickness[0.005], 
            Arrowheads[0.03], 
            Arrow[{{0, 2, 0}, {0, 3.07, 0}}], 
            Arrow[{{-2, 0, 0}, {-3, 0, 0}}], 
            Arrow[{{-1, -1, -2.121}, {-1.5, -1.5, -2.5}}], 
            
            Arrow[{{1.5, -1, -1.299}, {
              1.9, -1.5, -1.7}}]}}; $CellContext`fig2$ = {
           Opacity[0.3], 
           EdgeForm[], 
           Ellipsoid[{0, 0, 0}, {2, 2, 3}], {
            FaceForm[Red], 
            Polygon[
             Map[Append[#, 0.998]& , 
              CirclePoints[1.886, 50]]]}}; $CellContext`fig3$ = {
           Thickness[0.004], 
           Text[
            Style["x", Bold, Italic], {-0.95, -0.8, -2.7}], 
           Line[{{-1.2, -0.8, -2.7}, {-2., -0.8, -2.7}}], 
           Text[
            Style["y", Bold, Italic], {-2., 0.4, -2.7}], 
           Line[{{-2., -0.8, -2.7}, {-2., 0, -2.7}}], 
           Text[
            Style["z", Bold, Italic], {-2., -0.8, -1.6}], 
           Line[{{-2., -0.8, -2.7}, {-2., -0.8, -1.9}}]}; $CellContext`fig4$ = {
           Opacity[$CellContext`opcz$], 
           FaceForm[$CellContext`colorzm$], 
           
           Polygon[{{$CellContext`x1$ + $CellContext`xt$, 
              
              0, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}, {$CellContext`x1$ + $CellContext`xt$ + $CellContext`s1$ + \
$CellContext`st$, 
              0, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}, {$CellContext`x1$ + $CellContext`xt$ + $CellContext`s1$ + \
$CellContext`st$, $CellContext`s1$ + $CellContext`st$, $CellContext`z1$ + \
$CellContext`zt$ + $CellContext`s1$ + $CellContext`st$}, {$CellContext`x1$ + \
$CellContext`xt$, $CellContext`s1$ + $CellContext`st$, $CellContext`z1$ + \
$CellContext`zt$ + $CellContext`s1$ + $CellContext`st$}}], 
           
           Polygon[{{$CellContext`x1$ + $CellContext`xt$, 
              0, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, 
              0, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, $CellContext`s1$ + \
$CellContext`st$, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$, $CellContext`s1$ + $CellContext`st$, $CellContext`z1$ + \
$CellContext`zt$}}], 
           Opacity[$CellContext`opcx$], 
           FaceForm[$CellContext`colorx$], 
           
           Polygon[{{$CellContext`x1$ + $CellContext`xt$ + $CellContext`s1$ + \
$CellContext`st$, 
              0, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, $CellContext`s1$ + \
$CellContext`st$, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, $CellContext`s1$ + \
$CellContext`st$, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}, {$CellContext`x1$ + $CellContext`xt$ + $CellContext`s1$ + \
$CellContext`st$, 
              0, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}}], 
           
           Polygon[{{$CellContext`x1$ + $CellContext`xt$, 
              0, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$, $CellContext`s1$ + $CellContext`st$, $CellContext`z1$ + \
$CellContext`zt$}, {$CellContext`x1$ + $CellContext`xt$, $CellContext`s1$ + \
$CellContext`st$, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}, {$CellContext`x1$ + $CellContext`xt$, 
              0, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}}], 
           Opacity[$CellContext`opcy$], 
           FaceForm[$CellContext`colory$], 
           
           Polygon[{{$CellContext`x1$ + $CellContext`xt$ + $CellContext`s1$ + \
$CellContext`st$, $CellContext`s1$ + $CellContext`st$, $CellContext`z1$ + \
$CellContext`zt$}, {$CellContext`x1$ + $CellContext`xt$, $CellContext`s1$ + \
$CellContext`st$, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$, $CellContext`s1$ + $CellContext`st$, $CellContext`z1$ + \
$CellContext`zt$ + $CellContext`s1$ + $CellContext`st$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, $CellContext`s1$ + \
$CellContext`st$, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}}], 
           
           Polygon[{{$CellContext`x1$ + $CellContext`xt$, 
              0, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, 
              0, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + $CellContext`s1$ + $CellContext`st$, 
              0, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}, {$CellContext`x1$ + $CellContext`xt$, 
              0, $CellContext`z1$ + $CellContext`zt$ + $CellContext`s1$ + \
$CellContext`st$}}]}; $CellContext`fig5$ = {
           Thickness[0.0025], 
           Arrowheads[0.01], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$), ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + $CellContext`arr$, ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$), ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$), ($CellContext`s1$ + $CellContext`stmax$)/
               2 + $CellContext`arr$, $CellContext`z1$ + $CellContext`zt$ + \
($CellContext`s1$ + $CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$), ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$), ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 + $CellContext`arr$}}], 
           Text[
            Subscript[
             Style["\[Sigma]", Bold, 10], 
             "xx"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + $CellContext`arr$ + 
             0.4, ($CellContext`s1$ + $CellContext`stmax$)/
             2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}], 
           Text[
            Subscript[
             Style["\[Tau]", Bold, 10], 
             "xy"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + 
             0.2, ($CellContext`s1$ + $CellContext`stmax$)/
              2 + $CellContext`arr$ + 
             0.3, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 + 0.2}], 
           Text[
            Subscript[
             Style["\[Tau]", Bold, 10], 
             "xz"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + 0.4, ($CellContext`s1$ + $CellContext`stmax$)/
             2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 + $CellContext`arr$ + 0.2}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$, ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ - $CellContext`arr$, \
($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$, ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$, ($CellContext`s1$ + \
$CellContext`stmax$)/
               2 - $CellContext`arr$, $CellContext`z1$ + $CellContext`zt$ + \
($CellContext`s1$ + $CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$, ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$, ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 - $CellContext`arr$}}]}; $CellContext`fig6$ = {
           Thickness[0.0025], 
           Arrowheads[0.01], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2, $CellContext`s1$ + $CellContext`stmax$, $CellContext`z1$ + \
$CellContext`zt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2 + $CellContext`arr$, $CellContext`s1$ + $CellContext`stmax$, \
$CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2, $CellContext`s1$ + $CellContext`stmax$, $CellContext`z1$ + \
$CellContext`zt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2, ($CellContext`s1$ + $CellContext`stmax$) + \
$CellContext`arr$, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2, $CellContext`s1$ + $CellContext`stmax$, $CellContext`z1$ + \
$CellContext`zt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2, $CellContext`s1$ + $CellContext`stmax$, $CellContext`z1$ + \
$CellContext`zt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2 + $CellContext`arr$}}], 
           Text[
            Subscript[
             Style["\[Tau]", Bold, 10], 
             "yx"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 + $CellContext`arr$ + 
             0.2, ($CellContext`s1$ + $CellContext`stmax$) + 
             0.3, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 - 0.2}], 
           Text[
            Subscript[
             Style["\[Sigma]", Bold, 10], 
             "yy"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, ($CellContext`s1$ + $CellContext`stmax$) + $CellContext`arr$ + 
             0.5, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}], 
           Text[
            Subscript[
             Style["\[Tau]", Bold, 10], 
             "yz"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$) + 
             
             0.3, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 + $CellContext`arr$ + 0.2}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, 
              0, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 - $CellContext`arr$, 
              0, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, 
              0, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, 
              0 - $CellContext`arr$, $CellContext`z1$ + $CellContext`zt$ + \
($CellContext`s1$ + $CellContext`stmax$)/2}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, 
              0, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/
               2}, {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, 
              0, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 - $CellContext`arr$}}]}; $CellContext`fig7$ = {
           Thickness[0.0025], 
           Arrowheads[0.01], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)}, {$CellContext`x1$ + $CellContext`xt$ + \
($CellContext`s1$ + $CellContext`stmax$)/
               2 + $CellContext`arr$, ($CellContext`s1$ + \
$CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)}, {$CellContext`x1$ + $CellContext`xt$ + \
($CellContext`s1$ + $CellContext`stmax$)/
               2, ($CellContext`s1$ + $CellContext`stmax$)/
               2 + $CellContext`arr$, $CellContext`z1$ + $CellContext`zt$ + \
($CellContext`s1$ + $CellContext`stmax$)}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$)}, {$CellContext`x1$ + $CellContext`xt$ + \
($CellContext`s1$ + $CellContext`stmax$)/
               2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + $CellContext`arr$}}], 
           Text[
            Subscript[
             Style["\[Tau]", Bold, 10], 
             "zx"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2 + $CellContext`arr$ + 
             0.2, ($CellContext`s1$ + $CellContext`stmax$)/2 - 
             0.1, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + 0.4}], 
           Text[
            Subscript[
             Style["\[Tau]", Bold, 10], 
             "zy"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2 + $CellContext`arr$, $CellContext`z1$ + $CellContext`zt$ + \
($CellContext`s1$ + $CellContext`stmax$) + 0.4}], 
           Text[
            Subscript[
             Style["\[Sigma]", Bold, 10], 
             "z"], {$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
             2, $CellContext`z1$ + $CellContext`zt$ + ($CellContext`s1$ + \
$CellContext`stmax$) + $CellContext`arr$ + 0.3}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2 - $CellContext`arr$, ($CellContext`s1$ + \
$CellContext`stmax$)/2, $CellContext`z1$ + $CellContext`zt$}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2, ($CellContext`s1$ + $CellContext`stmax$)/
               2 - $CellContext`arr$, $CellContext`z1$ + $CellContext`zt$}}], 
           
           Arrow[{{$CellContext`x1$ + $CellContext`xt$ + ($CellContext`s1$ + \
$CellContext`stmax$)/2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$}, {$CellContext`x1$ + \
$CellContext`xt$ + ($CellContext`s1$ + $CellContext`stmax$)/
               2, ($CellContext`s1$ + $CellContext`stmax$)/
              2, $CellContext`z1$ + $CellContext`zt$ - $CellContext`arr$}}]}; \
$CellContext`fig8$ = {
           Opacity[
            UnitStep[$CellContext`t2$ - ($CellContext`t2max - 0.001)]], 
           EdgeForm[{Black, Dashed, 
             Thickness[0.001]}], 
           FaceForm[], 
           
           Cuboid[{$CellContext`x1$, 
             0, $CellContext`z1$}, {$CellContext`x1$ + $CellContext`s1$, \
$CellContext`s1$, $CellContext`z1$ + $CellContext`s1$}], 
           FaceForm[Red], 
           Opacity[0.15], 
           
           Polygon[{{$CellContext`x1$, 
              0, $CellContext`z1$ + $CellContext`s1$}, {$CellContext`x1$ + \
$CellContext`s1$, 
              0, $CellContext`z1$ + $CellContext`s1$}, {$CellContext`x1$ + \
$CellContext`s1$, $CellContext`s1$, $CellContext`z1$ + $CellContext`s1$}, \
{$CellContext`x1$, $CellContext`s1$, $CellContext`z1$ + $CellContext`s1$}}]}; \
$CellContext`fig9$ = {
           Text[
            Style[
            "\!\(\*SubscriptBox[\(\[CapitalDelta]A\), \(x\)]\)", 10, Bold], {
            4., 0.5, 3.3}]}; $CellContext`fig10$ = {
           Text[
            Style[
            "\!\(\*SubscriptBox[\(\[CapitalDelta]A\), \(y\)]\)", 10, Bold], {
            5., -0.3, 2.2}]}; $CellContext`fig11$ = {
           Text[
            Style[
            "\!\(\*SubscriptBox[\(\[CapitalDelta]A\), \(z\)]\)", 10, Bold], {
            5., -0.3, 2.2}]}; $CellContext`fig13$ = {
           FaceForm[Red], 
           Polygon[{{0, 0, 3}, {0, 1, 3}, {1, 1, 3}, {1, 0, 3}}], 
           Thickness[0.003], 
           Arrowheads[0.02], 
           Arrow[{{0.5, 0.5, 3}, {2., 0.5, 3}}], 
           Arrow[{{0.5, 0.5, 3}, {0.5, 2., 3}}], 
           Arrow[{{0.5, 0.5, 3}, {0.5, 0.5, 4.5}}], 
           Arrow[{{0.5, 0.5, 3}, {2., 2., 4.5}}], Dashed, 
           Thickness[0.001], 
           Line[{{0.5, 0.5, 4.5}, {2., 2., 4.5}}], 
           Line[{{2., 2., 3}, {2., 2., 4.5}}], 
           Line[{{0.5, 2., 3}, {2., 2., 3}}], 
           Line[{{2., 0.5, 3}, {2., 2., 3}}], 
           Line[{{0.5, 0.5, 3}, {2., 2., 3}}]}; $CellContext`fig14$ = {
           Text[
            Style[
            "\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]F\",\n\
FontSize->12], \"z\"]\)", 8, Bold], {2.2, 2.2, 4.7}], 
           Text[
            Style[
            "\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]F\",\n\
FontSize->12], \"zz\"]\)", 8, Bold], {0.5, 0.5, 4.9}], 
           Text[
            Style[
            "\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]F\",\n\
FontSize->12], \"zx\"]\)", 8, Bold], {2.7, 0.3, 2.9}], 
           Text[
            Style[
            "\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]F\",\n\
FontSize->12], \"zy\"]\)", 8, Bold], {0.6, 2.9, 3.}], 
           Thickness[0.003], 
           Line[$CellContext`ptz$], 
           Text[
            Style[
            "\!\(\*SubscriptBox[\(\[CapitalDelta]A\), \(z\)]\)", 10, Bold], {
            0, -0.3, 2.8}]}; $CellContext`fig16$ = 
         Switch[$CellContext`ts$$, 1, 
           If[$CellContext`t2$ >= $CellContext`t2max - 
             0.001, {$CellContext`fig5$, $CellContext`fig9$}], 2, 
           
           If[$CellContext`t2$ >= $CellContext`t2max - 
             0.001, {$CellContext`fig6$, $CellContext`fig10$}], 3, 
           
           If[$CellContext`t2$ >= $CellContext`t2max - 
             0.001, {$CellContext`fig7$, $CellContext`fig11$}]]; \
$CellContext`fig17$ = 
         If[$CellContext`def$$ == 
           1, {$CellContext`fig13$, $CellContext`fig14$}]; 
        Switch[$CellContext`show$$, 0, 
          Graphics3D[$CellContext`fig1$, $CellContext`setting1$], 1, 
          Graphics3D[{$CellContext`fig8$, 
            
            Style[$CellContext`fig2$, 
             ClipPlanes -> {0, 0, -1, 
              1}], $CellContext`fig3$, $CellContext`fig16$, \
$CellContext`fig17$, 
            
            If[$CellContext`t2$ > 
             0, $CellContext`fig4$]}, $CellContext`setting1$]]], 
      "Specifications" :> {{{$CellContext`show$$, 0, 
          Spacer[0]}, {1 -> "on", 0 -> "off"}, ControlType -> RadioButton, 
         ControlPlacement -> 1}, {{$CellContext`def$$, 0, 
          Spacer[0]}, {1 -> "on", 0 -> "off"}, ControlType -> RadioButton, 
         ControlPlacement -> 2}, {{$CellContext`t1$$, 0, 
          Text[
           Style["stress components", Bold, 12]]}, 0, 5, ImageSize -> Tiny, 
         ControlType -> Trigger, 
         AppearanceElements -> {"PlayPauseButton", "ResetButton"}, 
         ControlPlacement -> 3}, {{$CellContext`ts$$, 3, 
          Spacer[0]}, {1 -> Text[
            Style[
             Grid[{{"x face"}}], Bold]], 2 -> Text[
            Style[
             Grid[{{"y face"}}], Bold]], 3 -> Text[
            Style[
             Grid[{{"z face"}}], Bold]]}, Appearance -> "Vertical", 
         ControlType -> RadioButton, ControlPlacement -> 
         4}, {{$CellContext`mx$$, 0, 
          Spacer[0]}, {1 -> "on", 0 -> "off"}, ControlType -> RadioButton, 
         ControlPlacement -> 5}, 
        Grid[{{
           Text[
            Style["stress at a point", Bold, 12]]}, {
           Manipulate`Place[1]}, {
           PaneSelector[{1 -> Grid[{{
                 Text[
                  Style[
                   
                   Grid[{{"stress definition"}, {"(z face as example)"}}, 
                    Alignment -> Left], Bold, 12]]}, {
                 Manipulate`Place[2]}, {
                 PaneSelector[{1 -> Grid[{{
                    Text[
                    Subscript[
                    Style["\[Tau]", Bold], "zx"]], 
                    Text["="], 
                    Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\*SubscriptBox[\(\
\[CapitalDelta]A\), \(z\)] \[RightArrow] 0\)]\)", Bold, 12]], 
                    Text[
                    Style[
                    "\!\(\*SubscriptBox[\(\[CapitalDelta]F\), \
\(zx\)]\)/\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]A\",\n\
FontSize->12], \"z\"]\)", Bold, 12]]}, {
                    Text[
                    Subscript[
                    Style["\[Tau]", Bold], "zy"]], 
                    Text["="], 
                    Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\*SubscriptBox[\(\
\[CapitalDelta]A\), \(z\)] \[RightArrow] 0\)]\)", Bold, 12]], 
                    Text[
                    Style[
                    "\!\(\*SubscriptBox[\(\[CapitalDelta]F\), \
\(zy\)]\)/\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]A\",\n\
FontSize->12], \"z\"]\)", Bold, 12]]}, {
                    Text[
                    Subscript[
                    Style["\[Sigma]", Bold], "zz"]], 
                    Text["="], 
                    Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\*SubscriptBox[\(\
\[CapitalDelta]A\), \(z\)] \[RightArrow] 0\)]\)", Bold, 12]], 
                    Text[
                    Style[
                    "\!\(\*SubscriptBox[\(\[CapitalDelta]F\), \
\(zz\)]\)/\!\(\*SubscriptBox[\n StyleBox[\"\[CapitalDelta]A\",\n\
FontSize->12], \"z\"]\)", Bold, 12]]}}]}, 
                  Dynamic[$CellContext`def$$]]}, {
                 Manipulate`Place[3]}, {
                 PaneSelector[{1 -> Grid[{{
                    Manipulate`Place[4]}, {
                    Text[
                    Style[
                    Grid[{{"stress tensor"}}, Alignment -> Left], Bold, 
                    12]]}, {
                    Manipulate`Place[5]}}, Alignment -> Left, 
                    Spacings -> {1, 1}]}, 
                  Dynamic[
                   
                   UnitStep[$CellContext`t1$$ - ($CellContext`t1max - 
                    0.001)]]]}, {
                 PaneSelector[{1 -> Grid[{{
                    Text[
                    Style["\[Sigma]", Bold, 12]], 
                    Text[
                    Style["=", Bold, 12]], 
                    Text[
                    Style[
                    
                    MatrixForm[{{
                    "\!\(\*SubscriptBox[\n StyleBox[\"\[Sigma]\",\n\
FontSize->12], \"xx\"]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(xy\)]\)", 
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(xz\)]\)"}, {
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(yx\)]\)", 
                    "\!\(\*SubscriptBox[\n StyleBox[\"\[Sigma]\",\n\
FontSize->12], \"yy\"]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(yz\)]\)"}, {
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(zx\)]\)", 
                    "\!\(\*SubscriptBox[\(\[Tau]\), \(zy\)]\)", 
                    "\!\(\*SubscriptBox[\n StyleBox[\"\[Sigma]\",\n\
FontSize->12], \"zz\"]\)"}}], Bold, 12]]}}]}, 
                  Dynamic[
                  UnitStep[$CellContext`t1$$ - ($CellContext`t1max - 
                    0.001)] $CellContext`mx$$]]}}, Alignment -> Left, 
               Spacings -> {1, 1}]}, 
            Dynamic[$CellContext`show$$]]}}, Alignment -> Left, 
         Spacings -> {1, 1}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{916., {341., 350.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`t1max = 
       5, $CellContext`t2max = $CellContext`t1max/5}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 245, 8, 230, "Title"],
Cell[1734, 45, 894, 24, 105, "Text"],
Cell[2631, 71, 1068, 33, 117, "Text"],
Cell[3702, 106, 163, 3, 45, "Text"],
Cell[3868, 111, 35878, 733, 715, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature cxTtyuQA@8#djC1L3j5pfxwT *)
